==> constants-float16-pinf-0.0.2.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Half-precision floating-point positive infinity.
*
* @module @stdlib/constants/float16/pinf
* @type {number}
*
* @example
* var FLOAT16_PINF = require( '@stdlib/constants-float16-pinf' );
* // returns +infinity
*/

// MODULES //

var Number = require( '@stdlib/number-ctor' );


// MAIN //

/**
* Half-precision floating-point positive infinity.
*
* ## Notes
*
* Half-precision floating-point positive infinity has the bit sequence
*
* ```binarystring
* 0 11111 0000000000
* ```
*
* This bit sequence corresponds to the unsigned 16-bit integer `31744` and to the HEX value `0x7c00`.
*
* @constant
* @type {number}
* @default infinity
* @see [half-precision floating-point format]{@link https://en.wikipedia.org/wiki/Half-precision_floating-point_format}
*/
var FLOAT16_PINF = Number.POSITIVE_INFINITY; // TODO: if, and when, float16 is natively available, assign the true constant; otherwise, fall back to float64


// EXPORTS //

module.exports = FLOAT16_PINF;

==> constants-float16-pinf-0.0.7.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Half-precision floating-point positive infinity.
*
* @module @stdlib/constants-float16-pinf
* @type {number}
*
* @example
* var FLOAT16_PINF = require( '@stdlib/constants-float16-pinf' );
* // returns +infinity
*/

// MODULES //

var Number = require( '@stdlib/number-ctor' );


// MAIN //

/**
* Half-precision floating-point positive infinity.
*
* ## Notes
*
* Half-precision floating-point positive infinity has the bit sequence
*
* ```binarystring
* 0 11111 0000000000
* ```
*
* This bit sequence corresponds to the unsigned 16-bit integer `31744` and to the HEX value `0x7c00`.
*
* @constant
* @type {number}
* @default infinity
* @see [half-precision floating-point format]{@link https://en.wikipedia.org/wiki/Half-precision_floating-point_format}
*/
var FLOAT16_PINF = Number.POSITIVE_INFINITY; // TODO: if, and when, float16 is natively available, assign the true constant; otherwise, fall back to float64


// EXPORTS //

module.exports = FLOAT16_PINF;
